##  Troubleshooting Synchronization Issues
  1. In the Synchronization Logging section, filter synchronization runs for the desired integration. Pay attention to runs with the ERROR and WARNING statuses.
  2. To view actions for a specific synchronization run, navigate to the Logging details page. You can filter items with the ERROR and WARNING statuses.
  3. Identify the root causes of the problem using log messages.
You can use the search field to find a specific fact sheet. If needed, update data in that fact sheet to fix the problem.
![Searching for a Fact Sheet by Its Name on the Logging Details Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748a4f67a441014a717bfdd9e8decb9_LowRes.png)
  4. Once you have fixed issues in your integration, check the results of the next synchronization run. You can also initiate a synchronization run manually. If the problem persists, contact SAP LeanIX for assistance.


YesNo
Send
